@@ -90,7 +90,8 @@ def _first_file(setup_cfg: str, prefix: str) -> Optional[str]:
     prefix = _case_insensitive_glob(prefix)
     path = _adjacent_filename(setup_cfg, prefix)
     for filename in glob.iglob(f'{path}*'):
-        return filename
+        if os.path.isfile(filename):
+            return filename
     else:
         return None
 
@@ -322,6 +323,7 @@ def format_file(
 
     cfg = configparser.ConfigParser()
     cfg.read_string(contents)
+    _clean_sections(cfg)
 
     # normalize names to underscores so sdist / wheel have the same prefix
     cfg['metadata']['name'] = cfg['metadata']['name'].replace('-', '_')
@@ -418,6 +420,16 @@ def format_file(
     return new_contents != contents
 
 
+def _clean_sections(cfg: configparser.ConfigParser) -> None:
+    """Removes any empty options and sections."""
+    for section in cfg.sections():
+        new_options = {k: v for k, v in cfg[section].items() if v}
+        if new_options:
+            cfg[section] = new_options
+        else:
+            cfg.pop(section)
+
+
 def _ver_type(s: str) -> Tuple[int, int]:
     try:
         return _to_ver(s)
